@@ -15,8 +15,8 @@
 
 void chsolve2(double **matrix, int n, double *y)
      {
-     register int i,j;
-     register double temp;
+     int i,j;
+     double temp;
 
      /*
      ** solve Fb =y
